import { useEffect, useMemo, useState } from 'react';
import { pending, setPendingResult } from './use-async';
export const useAsyncVoidCallback = (fn, deps) => {
    const [result, setResult] = useState({ state: 'pending' });
    const [controller, callback] = useMemo(() => {
        const controller = new AbortController();
        const { signal } = controller;
        return [
            controller,
            (...args) => fn({ pending, signal }, ...args).then(value => {
                if (!signal.aborted && value !== pending) {
                    setResult({ state: 'fulfilled', value });
                }
            }, reason => {
                if (!signal.aborted) {
                    setResult({ state: 'rejected', reason });
                }
            }),
        ];
    }, deps);
    useEffect(() => {
        setResult(setPendingResult);
    }, deps);
    useEffect(() => {
        return () => {
            controller.abort();
        };
    }, [controller]);
    return useMemo(() => [callback, result], [callback, result]);
};
