import { useEffect, useState } from 'react';
export const pending = Symbol('pending');
export const setPendingResult = (result) => {
    if (result.state === 'pending') {
        return result;
    }
    return { state: 'pending' };
};
export const useAsync = (fn, deps) => {
    const [result, setResult] = useState({ state: 'pending' });
    useEffect(() => {
        setResult(setPendingResult);
        const controller = new AbortController();
        const { signal } = controller;
        fn({ pending, signal }).then(value => {
            if (!signal.aborted && value !== pending) {
                setResult({
                    state: 'fulfilled',
                    value,
                });
            }
        }, reason => {
            if (!signal.aborted) {
                setResult({
                    state: 'rejected',
                    reason,
                });
            }
        });
        return () => {
            controller.abort();
        };
    }, deps);
    return result;
};
